@@ -49,8 +49,12 @@ Please make sure to specify valid ingredients after the \
 
 # Key strings to cut recipe metadata, as starting point
 KEY_STRINGS_CUT_FROM_RECIPE: List[str] = [
-    "source: ",
+    "source:",
     "submitted by",
-    "from: ",
+    "from:",
+    "\nfrom",
     "recipe by",
+    "created by",
+    "historical note",
+    "recipe from",
 ]
